#[repr(i32)]pub enum AttentionNormalizationOp {
kNONE = 0,
kSOFTMAX = 1,
}Expand description
! ! \enum AttentionNormalizationOp ! ! \brief Enumerates the operations that may be performed by the normalization in the attention subgraph. !
Variants
kNONE = 0
kSOFTMAX = 1
!< Apply softmax normalization on the attention scores on the s_kv dimension.