#[repr(i32)]pub enum CudaGraphStrategy {
kDISABLED = 0,
kWHOLE_GRAPH_CAPTURE = 1,
}Expand description
! ! \enum CudaGraphStrategy ! ! \brief Strategies available for CUDA graphs optimizations for JIT (Just-In-Time) inference. ! ! \see IRuntimeConfig::setCudaGraphStrategy(), IRuntimeConfig::getCudaGraphStrategy() !
Variants
kDISABLED = 0
! ! Do not use CUDA graphs optimizations for inference. !
kWHOLE_GRAPH_CAPTURE = 1
! ! Capture CUDA graphs for the entire model execution as a single graph. ! This strategy captures the complete computational graph of the model ! and executes it atomically on the GPU stream. ! For dynamic shapes inference, this strategy captures the CUDA graph ! after the shape-specialized kernels are compiled for a given shape. !