#[repr(i32)]pub enum CumulativeOperation {
kSUM = 0,
}Expand description
! ! \enum CumulativeOperation ! ! \brief Enumerates the cumulative operations that may be performed by a Cumulative layer. ! ! The table shows the initial value of each Cumulative operation. ! ! Operation | kFLOAT, kHALF, kBF16 | kINT32, kINT64 | ! ——— | –––––––––– | ––––––– | ! kSUM | +0.0 | 0 | !
Variants
kSUM = 0
!< Calculate cumulative sum.