DynamicShapesKernelSpecializationStrategy

Enum DynamicShapesKernelSpecializationStrategy 

#[repr(i32)]
pub enum DynamicShapesKernelSpecializationStrategy { kLAZY = 0, kEAGER = 1, kNONE = 2, }
! ! \enum DynamicShapesKernelSpecializationStrategy ! ! \brief Different kernel specialization strategies for dynamic shapes. ! ! Compilation behavior of dynamic shape kernels specialized for a new shape can be controlled at runtime. The user ! can either let the implementation compile a specialized kernel in the background, immediately or not choose to ! compile specialized kernels at all. ! ! \see IRuntimeConfig !

Variants



kLAZY = 0

! ! Strategy to compile shape-specialized kernels for new shapes in the background lazily. Until this kernel is ! compiled, a fallback kernel is used to run inference. Once the shape-specialized kernel is compiled, it is used ! for next inference. !



kEAGER = 1

! ! Strategy to compile shape-specialized kernels for new shapes eagerly in a blocking fashion. Kernels ! are immediately used for next inference. !



kNONE = 2

! ! Strategy to always use fallback kernels for inference, never compiling shape-specialized kernels. !