#[repr(i32)]pub enum ExecutionContextAllocationStrategy {
kSTATIC = 0,
kON_PROFILE_CHANGE = 1,
kUSER_MANAGED = 2,
}Expand description
! ! \enum ExecutionContextAllocationStrategy ! ! \brief Different memory allocation behaviors for IExecutionContext. ! ! IExecutionContext requires a block of device memory for internal activation tensors during inference. The user can ! either let the execution context manage the memory in various ways or allocate the memory themselves. ! ! \see ICudaEngine::createExecutionContext() ! \see IExecutionContext::setDeviceMemory() !
Variants
kSTATIC = 0
!< Default static allocation with the maximum size across all profiles.
kON_PROFILE_CHANGE = 1
!< Reallocate for a profile when it’s selected.
kUSER_MANAGED = 2
!< The user supplies custom allocation to the execution context.