#[repr(i32)]pub enum LoopOutput {
kLAST_VALUE = 0,
kCONCATENATE = 1,
kREVERSE = 2,
}Expand description
! ! \enum LoopOutput ! ! \brief Enum that describes kinds of loop outputs. !
Variants
kLAST_VALUE = 0
! Output value is value of tensor for last iteration.
kCONCATENATE = 1
! Output value is concatenation of values of tensor for each iteration, in forward order.
kREVERSE = 2
! Output value is concatenation of values of tensor for each iteration, in reverse order.