#[repr(i32)]pub enum PoolingType {
kMAX = 0,
kAVERAGE = 1,
kMAX_AVERAGE_BLEND = 2,
}Expand description
! ! \enum PoolingType ! ! \brief The type of pooling to perform in a pooling layer. !
Variants
kMAX = 0
!< Maximum over elements
kAVERAGE = 1
!< Average over elements. If the tensor is padded, the count includes the padding
kMAX_AVERAGE_BLEND = 2
!< Blending between max and average pooling: (1-blendFactor)maxPool + blendFactoravgPool