#[repr(i32)]pub enum PreviewFeature {
kALIASED_PLUGIN_IO_10_03 = 0,
kRUNTIME_ACTIVATION_RESIZE_10_10 = 1,
}Expand description
! ! \enum PreviewFeature ! ! \brief Define preview features ! ! Preview Features have been fully tested but are not yet as stable as other features in TensorRT. ! They are provided as opt-in features for at least one release. !
Variants
kALIASED_PLUGIN_IO_10_03 = 0
! ! Allows plugin I/O to be aliased when using IPluginV3OneBuildV2 !
kRUNTIME_ACTIVATION_RESIZE_10_10 = 1
! ! Allows IExecutionContext::updateDeviceMemorySizeForShapes to resize runner internal activation memory. ! Using this feature can reduce runtime memory requirement when the actual input tensor shapes are smaller than ! the maximum input tensor dimensions. !