#[repr(i32)]pub enum ProfilingVerbosity {
kLAYER_NAMES_ONLY = 0,
kNONE = 1,
kDETAILED = 2,
}Expand description
! ! \enum ProfilingVerbosity ! ! \brief List of verbosity levels of layer information exposed in NVTX annotations and in IEngineInspector. ! ! \see IBuilderConfig::setProfilingVerbosity(), ! IBuilderConfig::getProfilingVerbosity(), ! IEngineInspector !
Variants
kLAYER_NAMES_ONLY = 0
!< Print only the layer names. This is the default setting.
kNONE = 1
!< Do not print any layer information.
kDETAILED = 2
!< Print detailed layer information including layer names and layer parameters.