#[repr(i32)]pub enum SampleMode {
kSTRICT_BOUNDS = 0,
kWRAP = 1,
kCLAMP = 2,
kFILL = 3,
kREFLECT = 4,
}Expand description
! ! \brief Controls how ISliceLayer and IGridSample handle out-of-bounds coordinates. ! ! \see ISliceLayer and IGridSample !
Variants
kSTRICT_BOUNDS = 0
!< Fail with error when the coordinates are out of bounds.
kWRAP = 1
!< Coordinates wrap around periodically.
kCLAMP = 2
!< Out of bounds indices are clamped to bounds.
kFILL = 3
!< Use fill input value when coordinates are out of bounds.
kREFLECT = 4
!< Coordinates reflect. The axis of reflection is the middle of the perimeter pixel and the !< reflections are repeated indefinitely within the padded regions. Repeats values for a single !< pixel and throws error for zero pixels.