Module nvinfer1

Module nvinfer1 

Structs

Dims64
Dims Structure to define the dimensions of a tensor.
ErrorCode
autocxx bindings couldn’t be generated: This item name is used in multiple namespaces. At present, autocxx and cxx allow only one type of a given name. This limitation will be fixed in future. (Items found with this name: nvinfer1::ErrorCode, nvonnxparser::ErrorCode)
IActivationLayer
IActivationLayer
IAssertionLayer
IAssertionLayer
IAttention
IAttention
IAttentionBoundaryLayer
IAttentionBoundaryLayer
IAttentionInputLayer
IAttentionInputLayer
IAttentionOutputLayer
IAttentionOutputLayer
IBuilder
IBuilder
IBuilderConfig
IBuilderConfig
ICastLayer
ICastLayer
IConcatenationLayer
IConcatenationLayer
IConditionLayer
IConditionLayer
IConstantLayer
IConstantLayer
IConvolutionLayer
IConvolutionLayer
ICudaEngine
ICudaEngine
ICumulativeLayer
ICumulativeLayer
IDebugListener
IDeconvolutionLayer
IDeconvolutionLayer
IDequantizeLayer
IDequantizeLayer
IDistCollectiveLayer
IDistCollectiveLayer
IDynamicQuantizeLayer
IDynamicQuantizeLayer
IEinsumLayer
IEinsumLayer
IElementWiseLayer
IElementWiseLayer
IEngineInspector
IEngineInspector
IErrorRecorder
IExecutionContext
IExecutionContext
IFillLayer
IFillLayer
IGatherLayer
IGatherLayer
IGpuAllocator
IGridSampleLayer
IGridSampleLayer
IHostMemory
IHostMemory
IIdentityLayer
IIdentityLayer
IIfConditional
IIfConditional
IIfConditionalInputLayer
IIfConditionalInputLayer
IIfConditionalOutputLayer
IIfConditionalOutputLayer
IIteratorLayer
IIteratorLayer
IKVCacheUpdateLayer
IKVCacheUpdateLayer
ILRNLayer
ILRNLayer
ILayer
ILayer
ILogger
ILogger
ILoop
ILoop
ILoopBoundaryLayer
ILoopBoundaryLayer
ILoopOutputLayer
ILoopOutputLayer
IMatrixMultiplyLayer
IMatrixMultiplyLayer
IMoELayer
┌──────────────┐┌────────────────────────┐┌────────────────────────┐
│ hiddenStates ││selectedExpertsForTokens││scoresForSelectedExperts│
└──────────────┘└────────────────────────┘└────────────────────────┘
│                    │                    │
│                    │                    │
┌───────────────────────────────────────────────────────────────────────────────────┐
│                                                                                   │
│  ┌──────────────────────────┐                        ┌──────────────────────────┐ │
│  │      │  Expert 0   │     │         MOE            │      │  Expert i   │     │ │
│  │      │             │     │                        │      │             │     │ │
│  │  ┌────────┐    ┌────────┐│                        │  ┌────────┐    ┌────────┐│ │
│  │  │ fcGate │    │  fcUp  ││                        │  │ fcGate │    │  fcUp  ││ │
│  │  │        │    │        ││                        │  │        │    │        ││ │
│  │  └───┬────┘    └────┬───┘│                        │  └───┬────┘    └────┬───┘│ │
│  │      │              │    │                        │      │              │    │ │
│  │ ┌──────────┐        │    │                        │ ┌──────────┐        │    │ │
│  │ │activation│        │    │                        │ │activation│        │    │ │
│  │ └────┬─────┘        │    │                        │ └────┬─────┘        │    │ │
│  │      │              │    │       .......          │      │              │    │ │
│  │      └──────┬───────┘    │                        │      └──────┬───────┘    │ │
│  │             │            │                        │             │            │ │
│  │         ┌────────┐       │                        │         ┌────────┐       │ │
│  │         │  mul   │       │                        │         │  mul   │       │ │
│  │         └───┬────┘       │                        │         └───┬────┘       │ │
│  │             │            │                        │             │            │ │
│  │         ┌───▼────┐       │                        │         ┌───▼────┐       │ │
│  │         │ fcDown │       │                        │         │ fcDown │       │ │
│  │         └───┬────┘       │                        │         └───┬────┘       │ │
│  │             │            │                        │             │            │ │
│  │         ┌───▼────┐       │                        │         ┌───▼────┐       │ │
│  │         │output 0│       │                        │         │output i│       │ │
│  │         └───┬────┘       │                        │         └───┬────┘       │ │
│  └─────────────┼────────────┘                        └─────────────┼────────────┘ │
│                │                                                   │              │
│                └───────────────────┬───────────────────────────────┘              │
│                                    │                                              │
│                                    ▼                                              │
│                            ┌───────────────┐                                      │
│                            │  weightedSum  │                                      │
│                            └───────┬───────┘                                      │
└────────────────────────────────────│──────────────────────────────────────────────┘
▼
┌───────────────┐
│   moeOutput   │
└───────────────┘
INMSLayer
INMSLayer
INetworkDefinition
INetworkDefinition
INonZeroLayer
INonZero
INormalizationLayer
INormalizationLayer
IOneHotLayer
IOneHotLayer
IOptimizationProfile
IOptimizationProfile Optimization profile for dynamic input dimensions and shape tensors.
IOutputAllocator
IPaddingLayer
IPaddingLayer
IParametricReLULayer
IParametricReLULayer
IPluginRegistry
IPluginRegistry
IPoolingLayer
IPoolingLayer
IProfiler
IProgressMonitor
IQuantizeLayer
IQuantizeLayer
IRaggedSoftMaxLayer
IRaggedSoftMaxLayer
IRecurrenceLayer
IRecurrenceLayer
IReduceLayer
IReduceLayer
IRefitter
IRefitter
IResizeLayer
IResizeLayer
IReverseSequenceLayer
IReverseSequenceLayer
IRotaryEmbeddingLayer
IRotaryEmbeddingLayer
IRuntime
IRuntime
IRuntimeCache
IRuntimeCache
IRuntimeConfig
IRuntimeConfig
IScaleLayer
IScaleLayer
IScatterLayer
IScatterLayer
ISelectLayer
ISelectLayer
ISerializationConfig
ISerializationConfig
IShapeLayer
IShapeLayer
IShuffleLayer
IShuffleLayer
ISliceLayer
Slices an input tensor into an output tensor based on the offset and strides.
ISoftMaxLayer
ISoftMaxLayer
ISqueezeLayer
ISqueezeLayer
IStreamReaderV2
IStreamWriter
ITensor
ITensor
ITimingCache
ITimingCache
ITopKLayer
ITopKLayer
ITripLimitLayer
ITripLimitLayer
IUnaryLayer
IUnaryLayer
IUnsqueezeLayer
IUnsqueezeLayer
IVersionedInterface
IVersionedInterface
InterfaceInfo
InterfaceInfo
Permutation
Permutation
Weights
Weights

Enums

APILanguage
APILanguage
ActivationType
ActivationType
AttentionIOForm
AttentionIOForm
AttentionNormalizationOp
AttentionNormalizationOp
BoundingBoxFormat
BoundingBoxFormat
BuilderFlag
BuilderFlag
CausalMaskKind
CausalMaskKind
CollectiveOperation
CollectiveOperation
ComputeCapability
ComputeCapability
CudaGraphStrategy
CudaGraphStrategy
CumulativeOperation
CumulativeOperation
DataType
DataType The type of weights and tensors. The datatypes other than kBOOL, kINT32, and kINT64 are “activation datatypes,” as they often represent values corresponding to inference results.
DeviceType
DeviceType The device that this layer/network will execute on.
DynamicShapesKernelSpecializationStrategy
DynamicShapesKernelSpecializationStrategy
ElementWiseOperation
ElementWiseOperation
EngineCapability
EngineCapability
EngineStat
EngineStat
EngineValidity
enum EngineValidity Whether a TensorRT-RTX engine is likely to be valid on the current system. The value is determined by only inspecting the header, so even an engine marked kVALID or kSUBOPTIMAL may be invalid if the body has become corrupted. See [IRuntime::getEngineValidity()]
ExecutionContextAllocationStrategy
ExecutionContextAllocationStrategy
FillOperation
FillOperation
GatherMode
Control form of IGatherLayer
HardwareCompatibilityLevel
HardwareCompatibilityLevel
InterpolationMode
InterpolationMode
KVCacheMode
KVCacheMode
LayerInformationFormat
LayerInformationFormat
LayerType
LayerType
LoopOutput
LoopOutput
MatrixOperation
MatrixOperation
MemoryPoolType
MemoryPoolType
MoEActType
MoEActType
NetworkDefinitionCreationFlag
NetworkDefinitionCreationFlag
OptProfileSelector
OptProfileSelector
PaddingMode
PaddingMode
PoolingType
PoolingType
PreviewFeature
PreviewFeature
ProfilingVerbosity
ProfilingVerbosity
ReduceOperation
ReduceOperation
ResizeCoordinateTransformation
ResizeCoordinateTransformation
ResizeRoundMode
ResizeRoundMode
ResizeSelector
ResizeSelector
RuntimePlatform
RuntimePlatform
SampleMode
Controls how ISliceLayer and IGridSample handle out-of-bounds coordinates.
ScaleMode
Controls how shift, scale and power are applied in a Scale layer.
ScatterMode
ScatterMode
SeekPosition
SeekPosition Controls the seek mode of IStreamReaderV2.
SerializationFlag
SerializationFlag
TacticSource
TacticSource
TensorFormat
TensorFormat
TensorIOMode
TensorIOMode
TensorLocation
TensorLocation
TilingOptimizationLevel
TilingOptimizationLevel
TopKOperation
TopKOperation
TripLimit
TripLimit
UnaryOperation
UnaryOperation
WeightsRole
WeightsRole

Type Aliases

AllocatorFlags
BuilderFlags
Represents one or more BuilderFlag values using binary OR operations, e.g., 1U << BuilderFlag::kDEBUG.
Dims
Alias for Dims64.
IErrorRecorder_ErrorDesc
A typedef of a C-style string for reporting error descriptions.
IErrorRecorder_RefCount
A typedef of a 32-bit integer for reference counting.
NetworkDefinitionCreationFlags
Represents one or more NetworkDefinitionCreationFlag flags using binary OR operations. e.g., 1U << NetworkDefinitionCreationFlag::kPREFER_JIT_PYTHON_PLUGINS
SerializationFlags
Represents one or more SerializationFlag values using binary OR operations, e.g., 1U << SerializationFlag::kEXCLUDE_LEAN_RUNTIME
TacticSources
Represents a collection of one or more TacticSource values combine using bitwise-OR operations.
TempfileControlFlags
Represents a collection of one or more TempfileControlFlag values combined using bitwise-OR operations.
TensorFormats
It is capable of representing one or more TensorFormat by binary OR operations, e.g., 1U << TensorFormat::kCHW4 | 1U << TensorFormat::kCHW32.