CumulativeOperation

Enum CumulativeOperation 

#[repr(i32)]
pub enum CumulativeOperation { kSUM = 0, }
CumulativeOperation

Enumerates the cumulative operations that may be performed by a Cumulative layer.

The table shows the initial value of each Cumulative operation.

OperationkFLOAT, kHALF, kBF16kINT32, kINT64
kSUM+0.00

Variants



kSUM = 0

< Calculate cumulative sum.