#[repr(i32)]pub enum FillOperation {
kLINSPACE = 0,
kRANDOM_UNIFORM = 1,
kRANDOM_NORMAL = 2,
}Expand description
FillOperation
Enumerates the tensor fill operations that may performed by a fill layer.
See [IFillLayer]
Variants
kLINSPACE = 0
Compute each value via an affine function of its indices. For example, suppose the parameters for the IFillLayer are:
- Dimensions = [3,4]
- Alpha = 1
- Beta = [100,10]
Element [i,j] of the output is Alpha + Beta[0]*i + Beta[1]*j. Thus the output matrix is:
1 11 21 31 101 111 121 131 201 211 221 231
A static beta b is implicitly a 1D tensor, i.e. Beta = [b]. Output type must be INT32, INT64, or FLOAT.
kRANDOM_UNIFORM = 1
Randomly draw values from a uniform distribution. Output type must be FLOAT or HALF.
kRANDOM_NORMAL = 2
Randomly draw values from a normal distribution. Output type must be FLOAT or HALF.