#[repr(i32)]pub enum RuntimePlatform {
kSAME_AS_BUILD = 0,
kWINDOWS_AMD64 = 1,
}Expand description
RuntimePlatform
Describes the intended runtime platform (operating system and CPU architecture) for the execution of the TensorRT engine. TensorRT provides support for cross-platform engine compatibility when the target runtime platform is different from the build platform.
The cross-platform engine will not be able to run on the host platform it was built on.
When building a cross-platform engine that also requires version forward compatibility, kEXCLUDE_LEAN_RUNTIME must be set to exclude the target platform lean runtime.
The cross-platform engine might have performance differences compared to the natively built engine on the target platform.
See [IBuilderConfig::setRuntimePlatform()], IBuilderConfig::getRuntimePlatform()
Variants
kSAME_AS_BUILD = 0
No requirement for cross-platform compatibility. The engine constructed by TensorRT can only run on the identical platform it was built on.
kWINDOWS_AMD64 = 1
Designates the target platform for engine execution as Windows AMD64 system. Currently this flag can only be enabled when building engines on Linux AMD64 platforms.