TacticSource

Enum TacticSource 

#[repr(i32)]
pub enum TacticSource { kEDGE_MASK_CONVOLUTIONS = 0, kJIT_CONVOLUTIONS = 1, }
TacticSource

List of tactic sources for TensorRT.

See TacticSources, IBuilderConfig::setTacticSources(), IBuilderConfig::getTacticSources()

Variants



kEDGE_MASK_CONVOLUTIONS = 0

Enables convolution tactics implemented with edge mask tables. These tactics tradeoff memory for performance by consuming additional memory space proportional to the input size. Enabled by default.



kJIT_CONVOLUTIONS = 1

Enables convolution tactics implemented with source-code JIT fusion. The engine building time may increase when this is enabled. Enabled by default.