IAttentionBoundaryLayer

Struct IAttentionBoundaryLayer 

pub struct IAttentionBoundaryLayer { /* private fields */ }
IAttentionBoundaryLayer

This is a base class for Attention boundary layers.

Boundary layers are used to demarcate the boundaries of IAttention. Typically client code does not deal directly with the boundary layers. However, they are indirectly visible via method INetworkDefinition::getLayer(int32_t index).

Implementations

Source

impl IAttentionBoundaryLayer

pub fn getAttention(self: &IAttentionBoundaryLayer) -> *mut IAttention

Get a pointer to the IAttention associated with this boundary layer.