pub struct IAttentionInputLayer { /* private fields */ }Expand description
IAttentionInputLayer
This layer represents an input to an attention subgraph.
This layer is automatically created when an IAttention is created. Clients typically do not
deal with the layer directly, but instead specify its input via addAttention or IAttention::setInput.
An IAttentionInputLayer has three to four inputs and one output.