ICastLayer

Struct ICastLayer 

pub struct ICastLayer { /* private fields */ }
ICastLayer

A cast layer in a network.

This layer casts a given tensor to the datatype specified by toType.

Implementations

Source

impl ICastLayer

pub fn setToType(self: Pin<&mut ICastLayer>, toType: DataType)

Set cast layer output type.

  • toType The DataType of the output tensor.

Set the output type of the cast layer.

pub fn getToType(self: &ICastLayer) -> DataType

Return cast layer output type.

toType parameter set during layer creation or by setToType(). The return value is the output type of the cast layer.