IConcatenationLayer

Struct IConcatenationLayer 

pub struct IConcatenationLayer { /* private fields */ }
IConcatenationLayer

A concatenation layer in a network definition.

The output dimension along the concatenation axis is the sum of the corresponding input dimensions. Every other output dimension is the same as the corresponding dimension of the inputs.

All tensors must have the same dimensions except along the concatenation axis.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl IConcatenationLayer

pub fn setAxis(self: Pin<&mut IConcatenationLayer>, axis: i32)

Set the axis along which concatenation occurs.

The default axis is the number of tensor dimensions minus three, or zero if the tensor has fewer than three dimensions. For example, for a tensor with dimensions NCHW, it is C.

When running this layer on the DLA, the concatenation axis must be the third to last axis, e.g. C if tensor dimensions are NCHW.

  • axis The axis along which concatenation occurs.
pub fn getAxis(self: &IConcatenationLayer) -> i32

Get the axis along which concatenation occurs.

See [setAxis()]