IConstantLayer

Struct IConstantLayer 

pub struct IConstantLayer { /* private fields */ }
IConstantLayer

Layer that represents a constant value.

This layer does not support boolean types.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl IConstantLayer

pub fn setWeights(self: Pin<&mut IConstantLayer>, weights: Weights)

Set the weights for the layer.

The output type is weights.type. If the network is weakly typed and the weights have a real type, the output type might be different per TensorRT’s type conversion rules.

See [getWeights()]

pub fn getWeights(self: &IConstantLayer) -> Weights

Get the weights for the layer.

See [setWeights]

pub fn setDimensions(self: Pin<&mut IConstantLayer>, dimensions: &Dims64)

Set the dimensions for the layer.

  • dimensions The dimensions of the layer

See [setDimensions]

pub fn getDimensions(self: &IConstantLayer) -> Dims64

Get the dimensions for the layer.

the dimensions for the layer

See [getDimensions]