IDebugListener

Struct IDebugListener 

pub struct IDebugListener { /* private fields */ }

Implementations

Source

impl IDebugListener

pub fn getInterfaceInfo<'a>( self: &'a IDebugListener, ) -> impl New<Output = InterfaceInfo> + 'a

Return version information associated with this interface. Applications must not override this method.

pub unsafe fn processDebugTensor( self: Pin<&mut IDebugListener>, addr: *const c_void, location: TensorLocation, type_: DataType, shape: &Dims64, name: *const c_char, stream: *mut CUstream_st, ) -> bool

Callback function that is called when a debug tensor’s value is updated and the debug state of the tensor is set to true. Content in the given address is only guaranteed to be valid for the duration of the callback.

  • location TensorLocation of the tensor.
  • addr pointer to buffer.
  • type data Type of the tensor.
  • shape shape of the tensor.
  • name name of the tensor.
  • stream CUDA stream object.

True on success, false otherwise.