IDeconvolutionLayer

Struct IDeconvolutionLayer 

pub struct IDeconvolutionLayer { /* private fields */ }
IDeconvolutionLayer

A deconvolution layer in a network definition.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl IDeconvolutionLayer

pub fn setNbOutputMaps(self: Pin<&mut IDeconvolutionLayer>, nbOutputMaps: i64)

Set the number of output feature maps for the deconvolution.

If executing this layer on DLA, the number of output maps must be in the range [1,8192].

See [getNbOutputMaps()]

pub fn getNbOutputMaps(self: &IDeconvolutionLayer) -> i64

Get the number of output feature maps for the deconvolution.

See [setNbOutputMaps()]

pub fn setNbGroups(self: Pin<&mut IDeconvolutionLayer>, nbGroups: i64)

Set the number of groups for a deconvolution.

The input tensor channels are divided into nbGroups groups, and a deconvolution is executed for each group, using a filter per group. The results of the group convolutions are concatenated to form the output.

If executing this layer on DLA, nbGroups must be one

When using groups in int8 mode, the size of the groups (i.e. the channel count divided by the group count) must be a multiple of 4 for both input and output.

Default: 1

See [getNbGroups()]

pub fn getNbGroups(self: &IDeconvolutionLayer) -> i64

Get the number of groups for a deconvolution.

See [setNbGroups()]

pub fn setKernelWeights(self: Pin<&mut IDeconvolutionLayer>, weights: Weights)

Set the kernel weights for the deconvolution.

The weights are specified as a contiguous array in CKRS order, where C the number of input channels, K the number of output feature maps, and R and S are the height and width of the filter.

See [getWeights()]

pub fn getKernelWeights(self: &IDeconvolutionLayer) -> Weights

Get the kernel weights for the deconvolution.

See [setNbGroups()]

pub fn setBiasWeights(self: Pin<&mut IDeconvolutionLayer>, weights: Weights)

Set the bias weights for the deconvolution.

Bias is optional. To omit bias, set the count value of the weights structure to zero.

The bias is applied per-feature-map, so the number of weights (if non-zero) must be equal to the number of output feature maps.

See [getBiasWeights()]

pub fn getBiasWeights(self: &IDeconvolutionLayer) -> Weights

Get the bias weights for the deconvolution.

See [getBiasWeights()]

pub fn setPrePadding(self: Pin<&mut IDeconvolutionLayer>, padding: &Dims64)

Set the multi-dimension pre-padding of the deconvolution.

The output will be trimmed by this number of elements on the start of every dimension. In other words, it resembles the inverse of a convolution layer with this padding size. Negative padding is not supported.

Default: (0, 0, …, 0)

See [getPrePadding()]

pub fn getPrePadding(self: &IDeconvolutionLayer) -> Dims64

Get the pre-padding.

See [setPrePadding()]

pub fn setPostPadding(self: Pin<&mut IDeconvolutionLayer>, padding: &Dims64)

Set the multi-dimension post-padding of the deconvolution.

The output will be trimmed by this number of elements on the end of every dimension. In other words, it resembles the inverse of a convolution layer with this padding size. Negative padding is not supported.

Default: (0, 0, …, 0)

See [getPostPadding()]

pub fn getPostPadding(self: &IDeconvolutionLayer) -> Dims64

Get the padding.

See [setPostPadding()]

pub fn setPaddingMode( self: Pin<&mut IDeconvolutionLayer>, paddingMode: PaddingMode, )

Set the padding mode.

Padding mode takes precedence if both setPaddingMode and setPre/PostPadding are used.

Default: kEXPLICIT_ROUND_DOWN

See [getPaddingMode()]

pub fn getPaddingMode(self: &IDeconvolutionLayer) -> PaddingMode

Get the padding mode.

Default: kEXPLICIT_ROUND_DOWN

See [setPaddingMode()]

pub fn setKernelSizeNd(self: Pin<&mut IDeconvolutionLayer>, kernelSize: &Dims64)

Set the multi-dimension kernel size of the deconvolution.

If executing this layer on DLA, there are two restrictions:

  1. Only 2D Kernel is supported.
  2. Kernel height and width must be in the range [1,32] or the combinations of [64, 96, 128] in one dimension and 1 in the other dimensions, i.e. [1x64] or [64x1] are valid, but not [64x64].

See [getKernelSizeNd()]

pub fn getKernelSizeNd(self: &IDeconvolutionLayer) -> Dims64

Get the multi-dimension kernel size of the deconvolution.

See [setKernelSizeNd()]

pub fn setStrideNd(self: Pin<&mut IDeconvolutionLayer>, stride: &Dims64)

Set the multi-dimension stride of the deconvolution.

Default: (1, 1, …, 1)

If executing this layer on DLA, there are two restrictions:

  1. Only 2D Stride is supported.
  2. Stride height and width must be in the range [1,32] or the combinations of [64, 96, 128] in one dimension and 1 in the other dimensions, i.e. [1x64] or [64x1] are valid, but not [64x64].

See [getStrideNd()]

pub fn getStrideNd(self: &IDeconvolutionLayer) -> Dims64

Get the multi-dimension stride of the deconvolution.

See [setStrideNd()]

pub fn setPaddingNd(self: Pin<&mut IDeconvolutionLayer>, padding: &Dims64)

Set the multi-dimension padding of the deconvolution.

The output will be trimmed by this number of elements on both sides of every dimension. In other words, it resembles the inverse of a convolution layer with this padding size. Padding is symmetric, and negative padding is not supported.

Default: (0, 0, …, 0)

If executing this layer on DLA, padding must be 0.

See [getPaddingNd()] setPadding() getPadding()

pub fn getPaddingNd(self: &IDeconvolutionLayer) -> Dims64

Get the multi-dimension padding of the deconvolution.

If the padding is asymmetric, the pre-padding is returned.

See [setPaddingNd()]

pub fn setDilationNd(self: Pin<&mut IDeconvolutionLayer>, dilation: &Dims64)

Set the multi-dimension dilation of the deconvolution.

Default: (1, 1, …, 1)

See [getDilationNd()]

pub fn getDilationNd(self: &IDeconvolutionLayer) -> Dims64

Get the multi-dimension dilation of the deconvolution.

See [setDilationNd()]