IHostMemory

Struct IHostMemory 

pub struct IHostMemory { /* private fields */ }
IHostMemory

Class to handle library allocated memory that is accessible to the user.

The memory allocated via the host memory object is owned by the library and will be de-allocated when the destroy method is called.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl IHostMemory

pub fn data(self: &IHostMemory) -> *mut c_void

A pointer to the raw data that is owned by the library.

pub fn size(self: &IHostMemory) -> usize

The size in bytes of the data that was allocated.

pub fn type_(self: &IHostMemory) -> DataType

The type of the memory that was allocated.