IIteratorLayer

Struct IIteratorLayer 

pub struct IIteratorLayer { /* private fields */ }
IIteratorLayer

A layer to do iterations.

The iterator layer iterates over a tensor along the given axis and in the given direction. It enables each loop iteration to inspect a different slice of the tensor.

See ILoop::addIterator()

Implementations

Source

impl IIteratorLayer

pub fn setAxis(self: Pin<&mut IIteratorLayer>, axis: i32)

Set axis to iterate over.

pub fn getAxis(self: &IIteratorLayer) -> i32

Get axis being iterated over.

pub fn setReverse(self: Pin<&mut IIteratorLayer>, reverse: bool)

Set iteration order to be reverse.

For reverse=false, the layer is equivalent to addGather(tensor, I, 0) where I is a scalar tensor containing the loop iteration number. For reverse=true, the layer is equivalent to addGather(tensor, M-1-I, 0) where M is the trip count computed from TripLimits of kind kCOUNT. The default is reverse=false.

pub fn getReverse(self: &IIteratorLayer) -> bool

Check if the iteration order is reverse.

True if and only if reversing input.