ILRNLayer

Struct ILRNLayer 

pub struct ILRNLayer { /* private fields */ }
ILRNLayer

A LRN layer in a network definition.

The output size is the same as the input size.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl ILRNLayer

pub fn setWindowSize(self: Pin<&mut ILRNLayer>, windowSize: i64)

Set the LRN window size.

The window size must be odd and in the range of [1, 15].

If executing this layer on the DLA, only values in the set, [3, 5, 7, 9], are valid.

See [setWindowStride()]

pub fn getWindowSize(self: &ILRNLayer) -> i64

Get the LRN window size.

See [getWindowStride()]

pub fn setAlpha(self: Pin<&mut ILRNLayer>, alpha: f32)

Set the LRN alpha value.

The valid range is [-1e20, 1e20].

See [getAlpha()]

pub fn getAlpha(self: &ILRNLayer) -> f32

Get the LRN alpha value.

See [setAlpha()]

pub fn setBeta(self: Pin<&mut ILRNLayer>, beta: f32)

Set the LRN beta value.

The valid range is [0.01, 1e5f].

See [getBeta()]

pub fn getBeta(self: &ILRNLayer) -> f32

Get the LRN beta value.

See [setBeta()]

pub fn setK(self: Pin<&mut ILRNLayer>, k: f32)

Set the LRN K value.

The valid range is [1e-5, 1e10].

See [getK()]

pub fn getK(self: &ILRNLayer) -> f32

Get the LRN K value.

See [setK()]