ILayer

Struct ILayer 

pub struct ILayer { /* private fields */ }
ILayer

Base class for all layer classes in a network definition.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl ILayer

pub fn getType(self: &ILayer) -> LayerType

Return the type of a layer.

See LayerType

pub unsafe fn setName(self: Pin<&mut ILayer>, name: *const c_char)

Set the name of a layer.

This method copies the name string.

The string name must be null-terminated, and be at most 4096 bytes including the terminator.

See [getName()]

pub fn getName(self: &ILayer) -> *const c_char

Return the name of a layer.

See [setName()]

pub fn getNbInputs(self: &ILayer) -> i32

Get the number of inputs of a layer.

pub fn getInput(self: &ILayer, index: i32) -> *mut ITensor

Get the layer input corresponding to the given index.

  • index The index of the input tensor.

The input tensor, or nullptr if the index is out of range or the tensor is optional ( ISliceLayer).

pub fn getNbOutputs(self: &ILayer) -> i32

Get the number of outputs of a layer.

pub fn getOutput(self: &ILayer, index: i32) -> *mut ITensor

Get the layer output corresponding to the given index.

The indexed output tensor, or nullptr if the index is out of range or the tensor is optional.

pub fn setInput(self: Pin<&mut ILayer>, index: i32, tensor: Pin<&mut ITensor>)

Replace an input of this layer with a specific tensor.

  • index the index of the input to modify.
  • tensor the new input tensor

Except for IFillLayer, ILoopOutputLayer, INMSLayer, IResizeLayer, IShuffleLayer, and ISliceLayer, this method cannot change the number of inputs to a layer. The index argument must be less than the value of getNbInputs().

See comments for overloads of setInput() for layers with special behavior.

pub fn getOutputType(self: &ILayer, index: i32) -> DataType

get the output type of this layer

  • index the index of the output

the inferred output type.

See [getOutputType()] outputTypeIsSet() resetOutputType()

pub unsafe fn setMetadata(self: Pin<&mut ILayer>, metadata: *const c_char)

Set the metadata for this layer.

The metadata is emitted in the JSON returned by IEngineInspector with ProfilingVerbosity set to kDETAILED.

  • metadata The per-layer metadata.

The string name must be null-terminated and be at most 4096 bytes including the terminator.

See [getMetadata()] See [getLayerInformation()]

pub fn getMetadata(self: &ILayer) -> *const c_char

Get the metadata of the layer.

The metadata as a null-terminated C-style string. If setMetadata() has not been called, an empty string “” will be returned as a default value.

See [setMetadata()]

pub fn setNbRanks(self: Pin<&mut ILayer>, nbRanks: i32) -> bool

Set the number of ranks for multi-device execution.

Setting nbRanks > 1 is only allowed for specific layer types that support multi-device execution:

  • IDistCollectiveLayer: Determines output shape for kALL_GATHER and kREDUCE_SCATTER operations.

For attention layers, use IAttention::setNbRanks() instead. For all other layer types, nbRanks must be 1.

  • nbRanks The number of ranks for multi-device execution. Must be >= 1.

true if successful, false if the layer type does not support the specified nbRanks value.

See [getNbRanks()] See IAttention::setNbRanks()

pub fn getNbRanks(self: &ILayer) -> i32

Get the number of ranks for multi-device execution.

The number of ranks configured for multi-device execution. Default is 1.

See [setNbRanks()]