IProgressMonitor

Struct IProgressMonitor 

pub struct IProgressMonitor { /* private fields */ }

Implementations

Source

impl IProgressMonitor

pub fn getInterfaceInfo<'a>( self: &'a IProgressMonitor, ) -> impl New<Output = InterfaceInfo> + 'a

Return version information associated with this interface. Applications must not override this method.

pub unsafe fn phaseStart( self: Pin<&mut IProgressMonitor>, phaseName: *const c_char, parentPhase: *const c_char, nbSteps: i32, )

Signal that a phase of the optimizer has started.

  • phaseName The name of this phase for tracking purposes.
  • parentPhase The parent phase that this phase belongs to, or nullptr if there is no parent.
  • nbSteps The number of steps that are involved in this phase.

The phaseStart function signals to the application that the current phase is beginning, and that it has a certain number of steps to perform. If phaseParent is nullptr, then the phaseStart is beginning an independent phase, and if phaseParent is specified, then the current phase, specified by phaseName, is within the scope of the parent phase. nbSteps will always be a positive number. The phaseStart function implies that the first step is being executed. TensorRT will signal when each step is complete.

Phase names are human readable English strings which are unique within a single phase hierarchy but which can be reused once the previous instance has completed. Phase names and their hierarchies may change between versions of TensorRT.

See [phaseFinish]

pub unsafe fn stepComplete( self: Pin<&mut IProgressMonitor>, phaseName: *const c_char, step: i32, ) -> bool

Signal that a step of an optimizer phase has finished.

  • phaseName The name of the innermost phase being executed.
  • step The step number that was completed.

The stepComplete function signals to the application that TensorRT has finished the current step for the phase phaseName, and will move onto the next step if there is one. The application can return false for TensorRT to exit the build early. The step value will increase on subsequent calls in the range [0, nbSteps).

true to continue to the next step or false to stop the build.

pub unsafe fn phaseFinish( self: Pin<&mut IProgressMonitor>, phaseName: *const c_char, )

Signal that a phase of the optimizer has finished.

  • phaseName The name of the phase that has finished.

The phaseFinish function signals to the application that the phase is complete. This function may be called before all steps in the range [0, nbSteps) have been reported to stepComplete. This scenario can be triggered by error handling, internal optimizations, or when stepComplete returns false to request cancellation of the build.

See [phaseStart]