pub struct IRaggedSoftMaxLayer { /* private fields */ }Expand description
IRaggedSoftMaxLayer
A RaggedSoftmax layer in a network definition.
This layer takes a ZxS input tensor and an additional Zx1 bounds tensor holding the lengths of the Z sequences.
This layer computes a softmax across each of the Z sequences.
The output tensor is of the same size as the input tensor.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.