pub struct IRecurrenceLayer { /* private fields */ }Expand description
IRecurrenceLayer
A recurrence layer in a network definition.
The recurrence layer allows a loop iteration to compute a result from a value computed in the previous iteration.