pub struct IReduceLayer { /* private fields */ }Expand description
IReduceLayer
Layer that represents a reduction across a non-bool tensor.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.
Implementations
Sourceimpl IReduceLayer
impl IReduceLayer
Sourcepub fn setOperation(self: Pin<&mut IReduceLayer>, op: ReduceOperation)
pub fn setOperation(self: Pin<&mut IReduceLayer>, op: ReduceOperation)
Set the reduce operation for the layer.
See [getOperation()], ReduceOperation
Sourcepub fn getOperation(self: &IReduceLayer) -> ReduceOperation
pub fn getOperation(self: &IReduceLayer) -> ReduceOperation
Get the reduce operation for the layer.
See [setOperation()], ReduceOperation
Sourcepub fn setReduceAxes(self: Pin<&mut IReduceLayer>, reduceAxes: u32)
pub fn setReduceAxes(self: Pin<&mut IReduceLayer>, reduceAxes: u32)
Set the axes over which to reduce.
See [getReduceAxes]
Sourcepub fn getReduceAxes(self: &IReduceLayer) -> u32
pub fn getReduceAxes(self: &IReduceLayer) -> u32
Get the axes over which to reduce for the layer.
See [setReduceAxes]
Sourcepub fn setKeepDimensions(self: Pin<&mut IReduceLayer>, keepDimensions: bool)
pub fn setKeepDimensions(self: Pin<&mut IReduceLayer>, keepDimensions: bool)
Set the boolean that specifies whether or not to keep the reduced dimensions for the layer.
See [getKeepDimensions]
Sourcepub fn getKeepDimensions(self: &IReduceLayer) -> bool
pub fn getKeepDimensions(self: &IReduceLayer) -> bool
Get the boolean that specifies whether or not to keep the reduced dimensions for the layer.
See [setKeepDimensions]