IRuntimeCache

Struct IRuntimeCache 

pub struct IRuntimeCache { /* private fields */ }
IRuntimeCache

A class for Runtime cache currently used for TensorRT JIT compilation. This cache can be serialized and deserialized to support persistence in disk files.

See [IRuntimeConfig::createRuntimeConfig()]

Implementations

Source

impl IRuntimeCache

pub fn serialize(self: &IRuntimeCache) -> *mut IHostMemory

Serialize the Runtime cache to a stream.

A IHostMemory object that contains the serialized Runtime cache.

pub unsafe fn deserialize( self: Pin<&mut IRuntimeCache>, blob: *const c_void, size: usize, ) -> bool

Deserialize the Runtime cache from a stream that contains serialized Runtime cache.

  • blob The serialized Runtime cache.
pub fn reset(self: Pin<&mut IRuntimeCache>) -> bool

Reset the Runtime cache. Clears all content within the cache.