ISelectLayer

Struct ISelectLayer 

pub struct ISelectLayer { /* private fields */ }
ISelectLayer

Select elements from two data tensors based on a condition tensor.

The select layer makes elementwise selections from two data tensors based on a condition tensor, behaving similarly to the numpy.where function with three parameters. The three input tensors must share the same rank. Multidirectional broadcasting is supported. The output tensor has the dimensions of the inputs AFTER applying the broadcast rule.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.