pub struct ISqueezeLayer { /* private fields */ }Expand description
ISqueezeLayer
Layer that represents a squeeze operation, removing unit dimensions of the first input tensor on a set of axes specified by the second input tensor.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.