IStreamReaderV2

Struct IStreamReaderV2 

pub struct IStreamReaderV2 { /* private fields */ }

Implementations

Source

impl IStreamReaderV2

pub fn getInterfaceInfo<'a>( self: &'a IStreamReaderV2, ) -> impl New<Output = InterfaceInfo> + 'a

Return version information associated with this interface. Applications must not override this method.

pub unsafe fn read( self: Pin<&mut IStreamReaderV2>, destination: *mut c_void, nbBytes: i64, stream: *mut CUstream_st, ) -> i64

Read the next number of bytes in the stream asynchronously.

  • destination The memory to write to, call cudaPointerGetAttributes to get the memory location

  • nbBytes The number of bytes to read

  • stream The CUDA stream used to do the copy

  • Returns The number of bytes read. Negative values indicate an unrecoverable error. A zero indicates that the end of the stream has been reached.

pub fn seek( self: Pin<&mut IStreamReaderV2>, offset: i64, where_: SeekPosition, ) -> bool

Sets the position of the stream to the given offset.

  • offset The number of bytes to offset from where.

  • where The position from where the offset is added. See SeekPosition

  • Returns True if the position is updated successfully.