pub struct IStreamWriter { /* private fields */ }Implementations
Sourceimpl IStreamWriter
impl IStreamWriter
Sourcepub fn getInterfaceInfo<'a>(
self: &'a IStreamWriter,
) -> impl New<Output = InterfaceInfo> + 'a
pub fn getInterfaceInfo<'a>( self: &'a IStreamWriter, ) -> impl New<Output = InterfaceInfo> + 'a
Return version information associated with this interface. Applications must not override this method.
Sourcepub unsafe fn write(
self: Pin<&mut IStreamWriter>,
data: *const c_void,
nbBytes: i64,
) -> i64
pub unsafe fn write( self: Pin<&mut IStreamWriter>, data: *const c_void, nbBytes: i64, ) -> i64
write nbBytes of data into the stream.
-
dataThe data to be written to stream -
nbBytesThe number of bytes to write -
Returns The number of bytes written. A value that is negative or less than nBytes indicates that an error occurred and TensorRT will give up on writing to the stream.