ITimingCache

Struct ITimingCache 

pub struct ITimingCache { /* private fields */ }
ITimingCache

Class to handle tactic timing info collected from builder.

The timing cache is created or initialized by IBuilderConfig. It can be shared across builder instances to reduce the builder wallclock time.

Rebuilding the same engine multiple times using the same timing cache will always yield a correct engine but the selected tactics and formats may vary between generated engine instances, if weak typing is used.

See IBuilderConfig

Deprecated in TensorRT-RTX 1.2. Timing cache operations are no-ops in TensorRT-RTX.