pub struct ITripLimitLayer { /* private fields */ }Expand description
ITripLimitLayer
A layer that represents a trip-count limiter.
The trip limit layer sets the execution condition for loops, using kCOUNT to define the number of iterations or kWHILE for a conditional loop. A loop can have one of each kind of limit, in which case the loop exits when the trip count is reached or the condition becomes false.
See INetworkDefinition::addTripLimit().
Implementations
Sourceimpl ITripLimitLayer
impl ITripLimitLayer
Sourcepub fn getTripLimit(self: &ITripLimitLayer) -> TripLimit
pub fn getTripLimit(self: &ITripLimitLayer) -> TripLimit
Get a trip limiter type.