pub struct IUnsqueezeLayer { /* private fields */ }Expand description
IUnsqueezeLayer
Layer that represents an unsqueeze operation, which reshapes the first input tensor by inserting unit-length dimensions to the output at the axes specified by the second input tensor.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.