#[repr(i32)]pub enum DataType {
kFLOAT = 0,
kHALF = 1,
kINT8 = 2,
kINT32 = 3,
kBOOL = 4,
kUINT8 = 5,
kFP8 = 6,
kBF16 = 7,
kINT64 = 8,
kINT4 = 9,
kFP4 = 10,
kE8M0 = 11,
}Expand description
DataType The type of weights and tensors. The datatypes other than kBOOL, kINT32, and kINT64 are “activation datatypes,” as they often represent values corresponding to inference results.
Variants
kFLOAT = 0
32-bit floating point format.
kHALF = 1
IEEE 16-bit floating-point format – has a 5 bit exponent and 11 bit significand.
kINT8 = 2
Signed 8-bit integer representing a quantized floating-point value.
kINT32 = 3
Signed 32-bit integer format.
kBOOL = 4
8-bit boolean. 0 = false, 1 = true, other values undefined.
kUINT8 = 5
Unsigned 8-bit integer format. Cannot be used to represent quantized floating-point values. Use the IdentityLayer to convert kUINT8 network-level inputs to {kFLOAT, kHALF} prior to use with other TensorRT layers, or to convert intermediate output before kUINT8 network-level outputs from {kFLOAT, kHALF} to kUINT8. kUINT8 conversions are only supported for {kFLOAT, kHALF}. kUINT8 to {kFLOAT, kHALF} conversion will convert the integer values to equivalent floating point values. {kFLOAT, kHALF} to kUINT8 conversion will convert the floating point values to integer values by truncating towards zero. This conversion has undefined behavior for floating point values outside the range [0.0F, 256.0F) after truncation. kUINT8 conversions are not supported for {kINT8, kINT32, kBOOL}.
kFP8 = 6
Signed 8-bit floating point with 1 sign bit, 4 exponent bits, 3 mantissa bits, and exponent-bias 7.
kBF16 = 7
Brain float – has an 8 bit exponent and 8 bit significand.
kINT64 = 8
Signed 64-bit integer type.
kINT4 = 9
Signed 4-bit integer type.
kFP4 = 10
4-bit floating point type 1 bit sign, 2 bit exponent, 1 bit mantissa
kE8M0 = 11
Unsigned representation of exponent-only 8-bit floating point type for quantization scales