IPaddingLayer

Struct IPaddingLayer 

pub struct IPaddingLayer { /* private fields */ }
IPaddingLayer

Layer that represents a padding operation.

The padding layer adds zero-padding at the start and end of the input tensor. It supports padding only the last two dimensions. Applying negative padding results in cropping of the input.

To pad across any subset of dimensions, use ISliceLayer with SampleMode::kFILL.

Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.

Implementations

Source

impl IPaddingLayer

pub fn setPrePaddingNd(self: Pin<&mut IPaddingLayer>, padding: &Dims64)

Set the padding that is applied at the start of the tensor.

Negative padding results in trimming the edge by the specified amount.

Only 2 dimensional padding is currently supported.

See [getPrePaddingNd]

pub fn getPrePaddingNd(self: &IPaddingLayer) -> Dims64

Get the padding that is applied at the start of the tensor.

Only 2 dimensional padding is currently supported.

See [setPrePaddingNd]

pub fn setPostPaddingNd(self: Pin<&mut IPaddingLayer>, padding: &Dims64)

Set the padding that is applied at the end of the tensor.

Negative padding results in trimming the edge by the specified amount

Only 2 dimensional padding is currently supported.

See [getPostPaddingNd]

pub fn getPostPaddingNd(self: &IPaddingLayer) -> Dims64

Get the padding that is applied at the end of the tensor.

Only 2 dimensional padding is currently supported.

See [setPostPaddingNd]