#[repr(i32)]pub enum PreviewFeature {
kPROFILE_SHARING_0806 = 0,
kALIASED_PLUGIN_IO_10_03 = 1,
kRUNTIME_ACTIVATION_RESIZE_10_10 = 2,
kMULTIDEVICE_RUNTIME_10_16 = 3,
}Expand description
! ! \enum PreviewFeature ! ! \brief Define preview features ! ! Preview Features have been fully tested but are not yet as stable as other features in TensorRT. ! They are provided as opt-in features for at least one release. !
Variants
kPROFILE_SHARING_0806 = 0
! ! Allows optimization profiles to be shared across execution contexts. ! ! \deprecated Deprecated in TensorRT 10.0. The default value for this flag is on and can not be changed. !
kALIASED_PLUGIN_IO_10_03 = 1
! ! Allows plugin I/O to be aliased when using IPluginV3OneBuildV2 !
kRUNTIME_ACTIVATION_RESIZE_10_10 = 2
! ! Allows IExecutionContext::updateDeviceMemorySizeForShapes to resize runner internal activation memory. ! Using this feature can reduce runtime memory requirement when the actual input tensor shapes are smaller than ! the maximum input tensor dimensions. !
kMULTIDEVICE_RUNTIME_10_16 = 3
! ! Enabling multi-device mode in TRT. ! Allows building an engine that contains multi-device enabled nodes, ! such as IDistCollective. ! ! \note: The preview flag must be set if there are any layers in the ! INetworkDefinition that need multi-device capabilities. Otherwise, an engine cannot be built.