#[repr(i32)]pub enum NetworkDefinitionCreationFlag {
kSTRONGLY_TYPED = 0,
}Expand description
NetworkDefinitionCreationFlag
List of immutable network properties expressed at network creation time. NetworkDefinitionCreationFlag is used with createNetworkV2() to specify immutable properties of the network.
See [IBuilder::createNetworkV2]
Variants
kSTRONGLY_TYPED = 0
Mark the network to be strongly typed. Every tensor in the network has a data type defined in the network following only type inference rules and the inputs/operator annotations. Setting layer precision and layer output types is not allowed, and the network output types will be inferred based on the input types and the type inference rules.
Deprecated in TensorRT 11.0. Strongly typed mode is always enabled. This flag is retained for API compatibility but is ignored.