#[repr(i32)]pub enum TacticSource {
kCUBLAS = 0,
kCUBLAS_LT = 1,
kCUDNN = 2,
kEDGE_MASK_CONVOLUTIONS = 3,
kJIT_CONVOLUTIONS = 4,
}Expand description
TacticSource
List of tactic sources for TensorRT.
See TacticSources, IBuilderConfig::setTacticSources(), IBuilderConfig::getTacticSources()
Variants
kCUBLAS = 0
cuBLAS tactics. Disabled by default. Disabling kCUBLAS will cause the cuBLAS handle passed to plugins in attachToContext to be null. Deprecated in TensorRT 10.0.
kCUBLAS_LT = 1
cuBLAS LT tactics. Disabled by default. Deprecated in TensorRT 9.0.
kCUDNN = 2
cuDNN tactics. Disabled by default. Disabling kCUDNN will cause the cuDNN handle passed to plugins in attachToContext to be null. Deprecated in TensorRT 10.0.
kEDGE_MASK_CONVOLUTIONS = 3
Enables convolution tactics implemented with edge mask tables. These tactics tradeoff memory for performance by consuming additional memory space proportional to the input size. Enabled by default.
kJIT_CONVOLUTIONS = 4
Enables convolution tactics implemented with source-code JIT fusion. The engine building time may increase when this is enabled. Enabled by default.