pub struct IAttentionBoundaryLayer { /* private fields */ }Expand description
IAttentionBoundaryLayer
This is a base class for Attention boundary layers.
Boundary layers are used to demarcate the boundaries of IAttention.
Typically client code does not deal directly with the boundary layers.
However, they are indirectly visible via method INetworkDefinition::getLayer(int32_t index).
Implementations
Sourceimpl IAttentionBoundaryLayer
impl IAttentionBoundaryLayer
Sourcepub fn getAttention(self: &IAttentionBoundaryLayer) -> *mut IAttention
pub fn getAttention(self: &IAttentionBoundaryLayer) -> *mut IAttention
Get a pointer to the IAttention associated with this boundary layer.