pub struct ICastLayer { /* private fields */ }Expand description
ICastLayer
A cast layer in a network.
This layer casts a given tensor to the datatype specified by toType.
Implementations
Sourceimpl ICastLayer
impl ICastLayer
Sourcepub fn setToType(self: Pin<&mut ICastLayer>, toType: DataType)
pub fn setToType(self: Pin<&mut ICastLayer>, toType: DataType)
Set cast layer output type.
toTypeThe DataType of the output tensor.
Set the output type of the cast layer.
Sourcepub fn getToType(self: &ICastLayer) -> DataType
pub fn getToType(self: &ICastLayer) -> DataType
Return cast layer output type.
toType parameter set during layer creation or by setToType(). The return value is the output type of the cast layer.