pub struct IConstantLayer { /* private fields */ }Expand description
IConstantLayer
Layer that represents a constant value.
This layer does not support boolean types.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.
Implementations
Sourceimpl IConstantLayer
impl IConstantLayer
Sourcepub fn setWeights(self: Pin<&mut IConstantLayer>, weights: Weights)
pub fn setWeights(self: Pin<&mut IConstantLayer>, weights: Weights)
Set the weights for the layer.
The output type is weights.type. If the network is weakly typed and the weights have a real type, the output type might be different per TensorRT’s type conversion rules.
See [getWeights()]
Sourcepub fn getWeights(self: &IConstantLayer) -> Weights
pub fn getWeights(self: &IConstantLayer) -> Weights
Get the weights for the layer.
See [setWeights]
Sourcepub fn setDimensions(self: Pin<&mut IConstantLayer>, dimensions: &Dims64)
pub fn setDimensions(self: Pin<&mut IConstantLayer>, dimensions: &Dims64)
Set the dimensions for the layer.
dimensionsThe dimensions of the layer
See [setDimensions]
Sourcepub fn getDimensions(self: &IConstantLayer) -> Dims64
pub fn getDimensions(self: &IConstantLayer) -> Dims64
Get the dimensions for the layer.
the dimensions for the layer
See [getDimensions]