pub struct IDebugListener { /* private fields */ }Implementations
Sourceimpl IDebugListener
impl IDebugListener
Sourcepub fn getInterfaceInfo<'a>(
self: &'a IDebugListener,
) -> impl New<Output = InterfaceInfo> + 'a
pub fn getInterfaceInfo<'a>( self: &'a IDebugListener, ) -> impl New<Output = InterfaceInfo> + 'a
Return version information associated with this interface. Applications must not override this method.
Sourcepub unsafe fn processDebugTensor(
self: Pin<&mut IDebugListener>,
addr: *const c_void,
location: TensorLocation,
type_: DataType,
shape: &Dims64,
name: *const c_char,
stream: *mut CUstream_st,
) -> bool
pub unsafe fn processDebugTensor( self: Pin<&mut IDebugListener>, addr: *const c_void, location: TensorLocation, type_: DataType, shape: &Dims64, name: *const c_char, stream: *mut CUstream_st, ) -> bool
Callback function that is called when a debug tensor’s value is updated and the debug state of the tensor is set to true. Content in the given address is only guaranteed to be valid for the duration of the callback.
locationTensorLocation of the tensor.addrpointer to buffer.typedata Type of the tensor.shapeshape of the tensor.namename of the tensor.streamCUDA stream object.
True on success, false otherwise.