pub struct ILRNLayer { /* private fields */ }Expand description
ILRNLayer
A LRN layer in a network definition.
The output size is the same as the input size.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.
Implementations
Sourceimpl ILRNLayer
impl ILRNLayer
Sourcepub fn setWindowSize(self: Pin<&mut ILRNLayer>, windowSize: i64)
pub fn setWindowSize(self: Pin<&mut ILRNLayer>, windowSize: i64)
Set the LRN window size.
The window size must be odd and in the range of [1, 15].
If executing this layer on the DLA, only values in the set, [3, 5, 7, 9], are valid.
See [setWindowStride()]
Sourcepub fn getWindowSize(self: &ILRNLayer) -> i64
pub fn getWindowSize(self: &ILRNLayer) -> i64
Get the LRN window size.
See [getWindowStride()]
Sourcepub fn setAlpha(self: Pin<&mut ILRNLayer>, alpha: f32)
pub fn setAlpha(self: Pin<&mut ILRNLayer>, alpha: f32)
Set the LRN alpha value.
The valid range is [-1e20, 1e20].
See [getAlpha()]
Sourcepub fn setBeta(self: Pin<&mut ILRNLayer>, beta: f32)
pub fn setBeta(self: Pin<&mut ILRNLayer>, beta: f32)
Set the LRN beta value.
The valid range is [0.01, 1e5f].
See [getBeta()]