pub struct ILoopBoundaryLayer { /* private fields */ }Expand description
ILoopBoundaryLayer
This is a base class for Loop boundary layers.
The loop boundary layers are used to define loops within a network, enabling the implementation of recurrences. The boundary layers for a loop are created by class ILoop.
There are four kinds of boundary layers.
- ITripLimitLayer: controls the number of loop iterations.
- IIterationLayer: iterates over an input tensor.
- IRecurrenceLayer: returns an initial value or value from the previous loop iteration.
- ILoopOutputLayer: generates an output tensor from the loop iterations.
Implementations
Sourceimpl ILoopBoundaryLayer
impl ILoopBoundaryLayer
Sourcepub fn getLoop(self: &ILoopBoundaryLayer) -> *mut ILoop
pub fn getLoop(self: &ILoopBoundaryLayer) -> *mut ILoop
Get a pointer to ILoop associated with this boundary layer.