pub struct IMatrixMultiplyLayer { /* private fields */ }Expand description
IMatrixMultiplyLayer
Layer that represents a Matrix Multiplication.
Let A be op(getInput(0)) and B be op(getInput(1)) where op(x) denotes the corresponding MatrixOperation.
When A and B are matrices or vectors, computes the inner product A * B:
matrix * matrix -> matrix matrix * vector -> vector vector * matrix -> vector vector * vector -> scalar
Inputs of higher rank are treated as collections of matrices or vectors. The output will be a corresponding collection of matrices, vectors, or scalars.
For a dimension that is not one of the matrix or vector dimensions: If the dimension is 1 for one of the tensors but not the other tensor, the former tensor is broadcast along that dimension to match the dimension of the latter tensor. The number of these extra dimensions for A and B must match.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.
Implementations
Sourceimpl IMatrixMultiplyLayer
impl IMatrixMultiplyLayer
Sourcepub fn setOperation(
self: Pin<&mut IMatrixMultiplyLayer>,
index: i32,
op: MatrixOperation,
)
pub fn setOperation( self: Pin<&mut IMatrixMultiplyLayer>, index: i32, op: MatrixOperation, )
Set the operation for an input tensor.
indexInput tensor number (0 or 1).opNew operation.
See [getOperation()]
Sourcepub fn getOperation(self: &IMatrixMultiplyLayer, index: i32) -> MatrixOperation
pub fn getOperation(self: &IMatrixMultiplyLayer, index: i32) -> MatrixOperation
Get the operation for an input tensor.
indexInput tensor number (0 or 1).
See [setOperation()]