pub struct IOneHotLayer { /* private fields */ }Expand description
IOneHotLayer
A OneHot layer in a network definition.
The OneHot layer has three input tensors: Indices, Values, and Depth, one output tensor: Output, and an axis attribute.
- Indices is an Int32 tensor that determines which locations in Output to set as on_value.
- Values is a two-element (rank=1) tensor that consists of [off_value, on_value]
- Depth is an 0D tensor of type Int32 or Int64, which contains the depth (number of classes) of the one-hot encoding. The depth tensor must be a positive build-time constant.
- Output is a tensor with rank = rank(indices)+1, where the added dimension contains the one-hot encoding. The data types of Output is equal to the Values data type.
- Axis is a scalar specifying to which dimension of the output one-hot encoding is added. Valid range for axis is -rank(indices)-1 <= axis <= rank(indices).
The output is computed by copying off_values to all output elements, then setting on_value on the indices specified by the indices tensor. when axis = 0: output[indices[i, j, k], i, j, k] = on_value for all i, j, k and off_value otherwise.
when axis = -1: output[i, j, k, indices[i, j, k]] = on_value for all i, j, k and off_value otherwise.
Do not inherit from this class, as doing so will break forward-compatibility of the API and ABI.
Implementations
Sourceimpl IOneHotLayer
impl IOneHotLayer
Sourcepub fn setAxis(self: Pin<&mut IOneHotLayer>, axis: i32)
pub fn setAxis(self: Pin<&mut IOneHotLayer>, axis: i32)
Set the axis parameter.
See IOneHotLayer
Sourcepub fn getAxis(self: &IOneHotLayer) -> i32
pub fn getAxis(self: &IOneHotLayer) -> i32
Get the value of the axis parameter.