pub struct IProfiler { /* private fields */ }Implementations
Sourceimpl IProfiler
impl IProfiler
Sourcepub unsafe fn reportLayerTime(
self: Pin<&mut IProfiler>,
layerName: *const c_char,
ms: f32,
)
pub unsafe fn reportLayerTime( self: Pin<&mut IProfiler>, layerName: *const c_char, ms: f32, )
Layer time reporting callback.
layerNameThe name of the layer, set when constructing the network definition. If the engine is built with profiling verbosity set to kNONE, the layerName is the decimal index of the layer.msThe time in milliseconds to execute the layer.