pub struct IRuntimeCache { /* private fields */ }Expand description
IRuntimeCache
A class for Runtime cache currently used for TensorRT JIT compilation. This cache can be serialized and deserialized to support persistence in disk files.
See [IRuntimeConfig::createRuntimeConfig()]
Implementations
Sourceimpl IRuntimeCache
impl IRuntimeCache
Sourcepub fn serialize(self: &IRuntimeCache) -> *mut IHostMemory
pub fn serialize(self: &IRuntimeCache) -> *mut IHostMemory
Serialize the Runtime cache to a stream.
A IHostMemory object that contains the serialized Runtime cache.
Sourcepub unsafe fn deserialize(
self: Pin<&mut IRuntimeCache>,
blob: *const c_void,
size: usize,
) -> bool
pub unsafe fn deserialize( self: Pin<&mut IRuntimeCache>, blob: *const c_void, size: usize, ) -> bool
Deserialize the Runtime cache from a stream that contains serialized Runtime cache.
blobThe serialized Runtime cache.
Sourcepub fn reset(self: Pin<&mut IRuntimeCache>) -> bool
pub fn reset(self: Pin<&mut IRuntimeCache>) -> bool
Reset the Runtime cache. Clears all content within the cache.