pub struct IStreamReaderV2 { /* private fields */ }Implementations
Sourceimpl IStreamReaderV2
impl IStreamReaderV2
Sourcepub fn getInterfaceInfo<'a>(
self: &'a IStreamReaderV2,
) -> impl New<Output = InterfaceInfo> + 'a
pub fn getInterfaceInfo<'a>( self: &'a IStreamReaderV2, ) -> impl New<Output = InterfaceInfo> + 'a
Return version information associated with this interface. Applications must not override this method.
Sourcepub unsafe fn read(
self: Pin<&mut IStreamReaderV2>,
destination: *mut c_void,
nbBytes: i64,
stream: *mut CUstream_st,
) -> i64
pub unsafe fn read( self: Pin<&mut IStreamReaderV2>, destination: *mut c_void, nbBytes: i64, stream: *mut CUstream_st, ) -> i64
Read the next number of bytes in the stream asynchronously.
-
destinationThe memory to write to, call cudaPointerGetAttributes to get the memory location -
nbBytesThe number of bytes to read -
streamThe CUDA stream used to do the copy -
Returns The number of bytes read. Negative values indicate an unrecoverable error. A zero indicates that the end of the stream has been reached.
Sourcepub fn seek(
self: Pin<&mut IStreamReaderV2>,
offset: i64,
where_: SeekPosition,
) -> bool
pub fn seek( self: Pin<&mut IStreamReaderV2>, offset: i64, where_: SeekPosition, ) -> bool
Sets the position of the stream to the given offset.
-
offsetThe number of bytes to offset from where. -
whereThe position from where the offset is added. SeeSeekPosition -
Returns True if the position is updated successfully.